@@ -2,7 +2,7 @@ from pathlib import Path
 from rich import print
 import os
 import subprocess as sp
-from .helpers import abs_path
+import helpers as hp
 
 # helpers
 def _params(length=3):
@@ -13,7 +13,7 @@ def alias(name, executable, _params_length):
 
 def install():
     print("Installing pnpm...")
-    PATH = abs_path()
+    PATH = hp.abs_path()
 
     if 'zsh' in os.environ.get("SHELL", ""):
         print('Installing with zsh')
@@ -23,6 +23,6 @@ def install():
             
         with open(Path.home() / ".zshrc", 'a') as f:
             path = 'test'
-            executable = f"python3 {abs_path('/generator/generate')}"
+            executable = f"python3 {hp.abs_path('/generate')}"
             f.write(alias('pnpm', executable, 5))
             
\ No newline at end of file
